#ifndef _CONFIG_H_
#define _CONFIG_H_
@TOP@

/* Define this if you're running x86 architecture */
#undef __i386__

/* Define this if you're running x86 architecture */
#undef ARCH_X86

/* Define this if you're running Alpha architecture */
#undef __alpha__

/* Define this if you're running PowerPC architecture */
#undef __ppc__

/* Define this if you're running Sparc architecture */
#undef __sparc__ 

/* Define this if you have X11R6 installed */
#undef HAVE_X11

/* Define this if you have GNU getopt_long() implemented */
#undef HAVE_GETOPT_LONG

/* Define this if you have getpwuid_t() implemented */
#undef HAVE_GETPWUID_R

/* Define this is you have stdarg.h header file installed */
#undef HAVE_STDARGS

/* Define this if you have LIRC (liblir_client) installed */
#undef HAVE_LIRC

/* Define this if you have ORBit (libORBit) installed */
#undef HAVE_ORBIT

#undef HAVE_AA

/* Define this if you have libXv installed */
#undef HAVE_XV

/* Define this if you have libXinerama installed */
#undef HAVE_XINERAMA

/* Define this if you have libXxf86vm installed */
#undef HAVE_XF86VIDMODE

/* Define this if you have DPMS */
#undef HAVE_DPMS

/* Define this to add mrl browser into xitk lib */
#undef NEED_MRLBROWSER

/* Where scripts are */
#undef XINE_SCRIPTDIR

/* Path where catalog files will be. */
#undef XITK_LOCALE

/* Path where docs files will be. */
#undef XINE_DOCDIR

@BOTTOM@
#endif
